==> libwebsockets_4.0.20.orig.tar.gz: libwebsockets-4.0.20/lib/event-libs/libevent/private-lib-event-libs-libevent.h <==
/*
 * libwebsockets - small server side websockets and web server implementation
 *
 * Copyright (C) 2010 - 2019 Andy Green <andy@warmcat.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#include <event2/event.h>

struct lws_pt_eventlibs_libevent {
	struct event_base *io_loop;
	struct event *hrtimer;
	struct event *idle_timer;
};

struct lws_io_watcher_libevent {
	struct event *watcher;
	char		set;
};

struct lws_signal_watcher_libevent {
	struct event *watcher;
};

struct lws_context_eventlibs_libevent {
	int placeholder;
};

extern struct lws_event_loop_ops event_loop_ops_event;

==> libwebsockets-4.1.6.tar.gz: libwebsockets-4.1.6/lib/event-libs/libevent/private-lib-event-libs-libevent.h <==
/*
 * libwebsockets - small server side websockets and web server implementation
 *
 * Copyright (C) 2010 - 2019 Andy Green <andy@warmcat.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#include <event2/event.h>

struct lws_signal_watcher_libevent {
	struct event *watcher;
	struct lws_context *context;
};

struct lws_pt_eventlibs_libevent {
	struct event_base *io_loop;
	struct event *hrtimer;
	struct event *idle_timer;
	struct lws_signal_watcher_libevent w_sigint;
};

struct lws_io_watcher_libevent {
	struct event *watcher;
	struct lws_context *context;
	uint8_t actual_events;
	char		set;
};

struct lws_wsi_eventlibs_libevent {
	struct lws_io_watcher_libevent w_read;
	struct lws_io_watcher_libevent w_write;
};
